#ifndef EFL_EXE_IMPL_HH
#define EFL_EXE_IMPL_HH

#include "efl_exe.eo.hh"

namespace efl { 
inline ::efl::eolian::return_traits<Efl_Exe_Flags>::type Exe::exe_flags_get() const
{
   Efl_Exe_Flags __return_value =  ::efl_exe_flags_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Exe_Flags>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Exe::exe_flags_set( ::efl::eolian::in_traits<Efl_Exe_Flags>::type flags) const
{
    ::efl_exe_flags_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Exe_Flags,  ::efl::eolian::in_traits<Efl_Exe_Flags>::type>(flags));
}
inline ::efl::eolian::return_traits<int>::type Exe::exit_signal_get() const
{
   int __return_value =  ::efl_exe_exit_signal_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Exe::signal( ::efl::eolian::in_traits<Efl_Exe_Signal>::type sig) const
{
    ::efl_exe_signal(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Exe_Signal,  ::efl::eolian::in_traits<Efl_Exe_Signal>::type>(sig));
}
} 
namespace eo_cxx {
namespace efl { 
inline ::efl::eolian::return_traits<Efl_Exe_Flags>::type Exe::exe_flags_get() const
{
   Efl_Exe_Flags __return_value =  ::efl_exe_flags_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Exe_Flags>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Exe::exe_flags_set( ::efl::eolian::in_traits<Efl_Exe_Flags>::type flags) const
{
    ::efl_exe_flags_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Exe_Flags,  ::efl::eolian::in_traits<Efl_Exe_Flags>::type>(flags));
}
inline ::efl::eolian::return_traits<int>::type Exe::exit_signal_get() const
{
   int __return_value =  ::efl_exe_exit_signal_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Exe::signal( ::efl::eolian::in_traits<Efl_Exe_Signal>::type sig) const
{
    ::efl_exe_signal(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Exe_Signal,  ::efl::eolian::in_traits<Efl_Exe_Signal>::type>(sig));
}
inline efl::Exe::operator ::efl::Exe() const { return *static_cast< ::efl::Exe const*>(static_cast<void const*>(this)); }
inline efl::Exe::operator ::efl::Exe&() { return *static_cast< ::efl::Exe*>(static_cast<void*>(this)); }
inline efl::Exe::operator ::efl::Exe const&() const { return *static_cast< ::efl::Exe const*>(static_cast<void const*>(this)); }
} }
#endif
